pitcharraytools.list_nonspanning_subarrays_of_pitch_array
=========================================================

.. autofunction:: abjad.tools.pitcharraytools.list_nonspanning_subarrays_of_pitch_array.list_nonspanning_subarrays_of_pitch_array
